#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#


#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top80
    namespace eval ::widgets::$base {
        set set,origin 1
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.lab81 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$base.ent82 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::$base.lab83 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$base.ent84 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::$base.lab85 {
        array set save {-justify 1 -text 1}
    }
    namespace eval ::widgets::$base.but86 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$base.lab87 {
        array set save {-justify 1 -text 1}
    }
    namespace eval ::widgets::$base.but88 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$base.lab89 {
        array set save {-text 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist _TopLevel
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {
global widget
$widget(Entry1) insert end "200"
$widget(Entry2) insert end "1000"
}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 200x200+22+30; update
    wm maxsize $top 804 577
    wm minsize $top 116 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl"
    bindtags $top "$top Vtcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top80 {base} {
    if {$base == ""} {
        set base .top80
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel
    wm focusmodel $top passive
    wm geometry $top 315x134+72+239; update
    wm maxsize $top 804 577
    wm minsize $top 116 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "Fast Mode Test"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    label $top.lab81 \
        -text {I/O Address:} 
    vTcl:DefineAlias "$top.lab81" "Label1" vTcl:WidgetProc "Toplevel1" 1
    entry $top.ent82 \
        -background white -textvariable "$top\::ent82" 
    vTcl:DefineAlias "$top.ent82" "Entry1" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab83 \
        -text Times: 
    vTcl:DefineAlias "$top.lab83" "Label2" vTcl:WidgetProc "Toplevel1" 1
    entry $top.ent84 \
        -background white -textvariable "$top\::ent84" 
    vTcl:DefineAlias "$top.ent84" "Entry2" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab85 \
        -justify left -text {Click Normal Mode button to test.} 
    vTcl:DefineAlias "$top.lab85" "Label3" vTcl:WidgetProc "Toplevel1" 1
    button $top.but86 \
        \
        -command [list vTcl:DoCmdOption $top.but86 source\ ../ntport.tcl\n\n#\ Using\ normal\ mode\n::ntport::SetFastMode\ 0\n\ \ \ \ \n#\ Get\ the\ address\ of\ the\ port\nset\ nPort\ \[\$widget(Entry1)\ get\]\n\ \ \ \ \n#\ If\ you\ are\ using\ Evalualtion\ version,\ this\n#\ statement\ will\ show\ the\ registration\ reminder\n#\ dialog.\ If\ you\ are\ using\ the\ registered\ version,\n#\ please\ call\ LicesnseInfo\ instead.\nset\ nData\ \[::ntport::Inp\ \$nPort\]\n\ \ \ \ \n#\ Test\ the\ result\ of\ Inp\nset\ s\ \[::dll::buffer\ 100\]\nset\ nError\ \[::ntport::GetLastState\ s\]\nset\ s\ \[string\ range\ \$s\ 0\ \[expr\ \[string\ first\ \"\\x00\"\ \$s\]\ -\ 1\]\]\nif\ \{\$nError\ !=\ \[ERROR_NONE\]\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Error:\ \$s\"\ -title\ \"Error\"\ \\\n\ \ \ \ \ \ -icon\ error\n\ \ \ return\n\}\n\ \ \ \ \n#\ Start\ the\ time\ count\n::dll::load\ winmm.dll\ ->\ winmm\n::winmm::cmd\ \"int\ timeGetTime()\"\nset\ tTime\ \[::winmm::timeGetTime\]\n\ \ \ \ \n#\ Read\ the\ port\ in\ a\ loop\nset\ nTimes\ \[\$widget(Entry2)\ get\]\nfor\ \{set\ i\ 1\}\ \{\$i\ <\ \$nTimes\}\ \{incr\ i\}\ \{\n\ \ \ set\ nData\ \[::ntport::Inp\ \$nPort\]\n\}\n\ \ \ \ \n#\ Stop\ the\ time\ count\nset\ tTime\ \[expr\ \{\[::winmm::timeGetTime\]\ -\ \$tTime\}\]\n\ \ \ \ \n#\ Show\ the\ result\n\$widget(Label3)\ config\ -text\ \"Normal\ mode\ time\ cost:\ \[format\ \"%5.2f\"\ \$tTime\]ms\"] \
        -pady 0 -text {Normal Mode} 
    vTcl:DefineAlias "$top.but86" "ButtonNormal" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab87 \
        -justify left -text {Click Fast Mode button to test.} 
    vTcl:DefineAlias "$top.lab87" "Label4" vTcl:WidgetProc "Toplevel1" 1
    button $top.but88 \
        \
        -command [list vTcl:DoCmdOption $top.but88 source\ ../ntport.tcl\n\n#\ Check\ the\ OS\nif\ \{!\[::ntport::IsWinNT\]\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Fast\ mode\ is\ designed\ for\ Windows\ NT/2000/XP/Server\ 2003\ users,\ not\ Windows\ 95/98\ users!\"\ \\\n\ \ \ \ \ \ \ -title\ \"Error\"\ -icon\ error\n\ \ \ return\n\}\n\ \ \ \ \n#\ Using\ fast\ mode\n::ntport::SetFastMode\ 1\n\ \ \ \ \n#\ Get\ the\ address\ of\ the\ port\nset\ nPort\ \[\$widget(Entry1)\ get\]\n\ \ \ \ \n#\ To\ use\ the\ fast\ mode,\ you\ must\ call\ EnablePorts\n#\ before\ you\ call\ the\ Inport,\ Outport,\ and\ other\n#\ functions.\n::ntport::EnablePorts\ \$nPort\ \$nPort\n\n#\ Test\ the\ result\ of\ EnablePorts\nset\ s\ \[::dll::buffer\ 100\]\nset\ nError\ \[::ntport::GetLastState\ s\]\nset\ s\ \[string\ range\ \$s\ 0\ \[expr\ \[string\ first\ \"\\x00\"\ \$s\]\ -\ 1\]\]\nif\ \{\$nError\ !=\ \[ERROR_NONE\]\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Error:\ \$s\"\ -title\ \"Error\"\ \\\n\ \ \ \ \ \ -icon\ error\n\ \ \ return\n\}\n\ \ \ \ \n#\ If\ you\ are\ using\ Evalualtion\ version,\ this\n#\ statement\ will\ show\ the\ registration\ reminder\n#\ dialog.\ If\ you\ are\ using\ the\ registered\ version,\n#\ please\ call\ LicesnseInfo\ instead.\nset\ nData\ \[::ntport::Inp\ \$nPort\]\n\ \ \ \ \n#\ Test\ the\ result\ of\ Inp\nset\ s\ \[::dll::buffer\ 100\]\nset\ nError\ \[::ntport::GetLastState\ s\]\nset\ s\ \[string\ range\ \$s\ 0\ \[expr\ \[string\ first\ \"\\x00\"\ \$s\]\ -\ 1\]\]\nif\ \{\$nError\ !=\ \[ERROR_NONE\]\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Error:\ \$s\"\ -title\ \"Error\"\ \\\n\ \ \ \ \ \ -icon\ error\n\ \ \ return\n\}\n\ \ \ \ \n#\ Start\ the\ time\ count\n::dll::load\ winmm.dll\ ->\ winmm\n::winmm::cmd\ \"int\ timeGetTime()\"\nset\ tTime\ \[::winmm::timeGetTime\]\n\ \ \ \ \n#\ Read\ the\ port\ in\ a\ loop\nset\ nTimes\ \[\$widget(Entry2)\ get\]\nfor\ \{set\ i\ 1\}\ \{\$i\ <\ \$nTimes\}\ \{incr\ i\}\ \{\n\ \ \ set\ nData\ \[::ntport::Inp\ \$nPort\]\n\}\n\ \ \ \ \n#\ Stop\ the\ time\ count\nset\ tTime\ \[expr\ \{\[::winmm::timeGetTime\]\ -\ \$tTime\}\]\n\ \ \ \ \n#\ Free\ the\ resource\n::ntport::DisablePorts\ \$nPort\ \$nPort\n\n#\ Show\ the\ result\n\$widget(Label4)\ config\ -text\ \"Normal\ mode\ time\ cost:\ \[format\ \"%5.2f\"\ \$tTime\]ms\"] \
        -pady 0 -text {Fast Mode} 
    vTcl:DefineAlias "$top.but88" "ButtonFast" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab89 \
        -text {Copyright (c) 1997-2006 Zeal SoftStudio. www.zealsoft.com} 
    vTcl:DefineAlias "$top.lab89" "Label5" vTcl:WidgetProc "Toplevel1" 1
    ###################
    # SETTING GEOMETRY
    ###################
    place $top.lab81 \
        -in $top -x 10 -y 10 -anchor nw -bordermode ignore 
    place $top.ent82 \
        -in $top -x 80 -y 10 -width 36 -height 19 -anchor nw \
        -bordermode ignore 
    place $top.lab83 \
        -in $top -x 130 -y 10 -anchor nw -bordermode ignore 
    place $top.ent84 \
        -in $top -x 170 -y 10 -width 41 -height 19 -anchor nw \
        -bordermode ignore 
    place $top.lab85 \
        -in $top -x 10 -y 40 -width 178 -height 24 -anchor nw \
        -bordermode ignore 
    place $top.but86 \
        -in $top -x 215 -y 40 -width 74 -height 21 -anchor nw \
        -bordermode ignore 
    place $top.lab87 \
        -in $top -x 18 -y 70 -width 150 -height 19 -anchor nw \
        -bordermode ignore 
    place $top.but88 \
        -in $top -x 215 -y 70 -width 74 -height 21 -anchor nw \
        -bordermode ignore 
    place $top.lab89 \
        -in $top -x 15 -y 105 -width 278 -height 19 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}

Window show .
Window show .top80

main $argc $argv
