#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    # Provoke name search
    catch {package require bogus-package-name}
    set packageNames [package names]

    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
    # Needs Itcl
    package require Itcl

    # Needs Itk
    package require Itk

    # Needs Iwidgets
    package require Iwidgets

    switch $tcl_platform(platform) {
	windows {
            option add *Pushbutton.padY         0
	}
	default {
	    option add *Scrolledhtml.sbWidth    10
	    option add *Scrolledtext.sbWidth    10
	    option add *Scrolledlistbox.sbWidth 10
	    option add *Scrolledframe.sbWidth   10
	    option add *Hierarchy.sbWidth       10
            option add *Pushbutton.padY         2
        }
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#


#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top73
    namespace eval ::widgets::$base {
        set set,origin 1
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.lab74 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$base.ent75 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::$base.lab76 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$base.ent77 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::$base.lab78 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$base.lis79 {
        array set save {-background 1 -listvariable 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$base.but80 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$base.but81 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$base.but82 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::$base.lab90 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$base.lab73 {
        array set save {-labelfont 1 -labelpos 1 -labeltext 1}
    }
    set site_4_0 [$base.lab73 childsite]
    namespace eval ::widgets::$site_4_0 {
        array set save {}
    }
    set site_4_0 $site_4_0
    namespace eval ::widgets::$site_4_0.cpd74 {
        array set save {-text 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.cpd75 {
        array set save {-text 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.cpd76 {
        array set save {-text 1 -value 1 -variable 1}
    }
    namespace eval ::widgets::$base.scr79 {
        array set save {}
    }
    namespace eval ::widgets_bindings {
        set tagslist _TopLevel
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {
global widget
$widget(Radiobutton1) select
$widget(Entry1) insert end "61"
}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 200x200+22+30; update
    wm maxsize $top 804 577
    wm minsize $top 116 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl"
    bindtags $top "$top Vtcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top73 {base} {
    if {$base == ""} {
        set base .top73
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel
    wm focusmodel $top passive
    wm geometry $top 336x221+155+260; update
    wm maxsize $top 804 577
    wm minsize $top 116 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "Port Test Sample"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    label $top.lab74 \
        -text Address(Hex): 
    vTcl:DefineAlias "$top.lab74" "Label1" vTcl:WidgetProc "Toplevel1" 1
    entry $top.ent75 \
        -background white -textvariable "$top\::ent75" 
    vTcl:DefineAlias "$top.ent75" "Entry1" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab76 \
        -text Data(Hex): 
    vTcl:DefineAlias "$top.lab76" "Label2" vTcl:WidgetProc "Toplevel1" 1
    entry $top.ent77 \
        -background white -textvariable "$top\::ent77" 
    vTcl:DefineAlias "$top.ent77" "Entry2" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab78 \
        -text Result: 
    vTcl:DefineAlias "$top.lab78" "Label3" vTcl:WidgetProc "Toplevel1" 1
    listbox $top.lis79 \
        -background white -yscrollcommand "$top.scr79 set" \
        -listvariable "$top\::lis79" 
    vTcl:DefineAlias "$top.lis79" "Listbox1" vTcl:WidgetProc "Toplevel1" 1
    button $top.but80 \
        \
        -command [list vTcl:DoCmdOption $top.but80 global\ widget\nsource\ ../ntport.tcl\n\nscan\ \[\$widget(Entry1)\ get\]\ \"%x\"\ portID\nif\ \{\$portID\ <=\ 0\ ||\ \$portID\ >\ 0xffff\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Please\ input\ a\ valid\ port\ address!\"\\\n\ \ \ \ \ \ \ -title\ \"Error\"\ -icon\ error\n\ \ \ return\n\}\n\n::ntport::LicenseInfo\ \"Your\ user\ name\"\ 0\nswitch\ -exact\ --\ \[Toplevel1\ setvar\ selectedButton\]\ \{\n\ \ \ byte\ \{\ set\ inNum\ \[::ntport::Inp\ \$portID\]\ \}\n\ \ \ word\ \{\ set\ inNum\ \[::ntport::Inpw\ \$portID\]\ \}\n\ \ \ default\ \{\ set\ inNum\ \[::ntport::Inpd\ \$portID\]\ \}\n\}\n\$widget(Listbox1)\ insert\ end\ \"In\ \[format\ \"%#x\"\ \$portID\]H,\ \[format\ \"%#x\"\ \$inNum\]H\"\n\ \ \ \ \n#\ Get\ the\ result\ \nset\ s\ \[::dll::buffer\ 100\]\n::ntport::GetLastState\ s\nset\ s\ \[string\ range\ \$s\ 0\ \[expr\ \[string\ first\ \"\\x00\"\ \$s\]\ -\ 1\]\]\n\$widget(Listbox1)\ insert\ end\ \$s\n\$widget(Listbox1)\ see\ end] \
        -pady 0 -text Read 
    vTcl:DefineAlias "$top.but80" "btnRead" vTcl:WidgetProc "Toplevel1" 1
    button $top.but81 \
        \
        -command [list vTcl:DoCmdOption $top.but81 global\ widget\nsource\ ../ntport.tcl\n\nscan\ \[\$widget(Entry1)\ get\]\ \"%x\"\ portID\nif\ \{\$portID\ <=\ 0\ ||\ \$portID\ >\ 0xffff\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Please\ input\ a\ valid\ port\ address!\"\\\n\ \ \ \ \ \ \ -title\ \"Error\"\ -icon\ error\n\ \ \ return\n\}\nset\ sData\ \[\$widget(Entry2)\ get\]\nif\ \{\[string\ length\ \$sData\]\ ==\ 0\}\ \{\n\ \ \ tk_messageBox\ -message\ \"Please\ input\ output\ data!\"\\\n\ \ \ \ \ \ \ -title\ \"Error\"\ -icon\ error\n\ \ \ return\n\}\nscan\ \$sData\ \"%x\"\ outData\n\nswitch\ -exact\ --\ \[Toplevel1\ setvar\ selectedButton\]\ \{\n\ \ \ byte\ \{\ ::ntport::Outp\ \$portID\ \$outData\ \}\n\ \ \ word\ \{\ ::ntport::Outpw\ \$portID\ \$outData\ \}\n\ \ \ default\ \{\ ::ntport::Outpd\ \$portID\ \$outData\ \}\n\}\n\$widget(Listbox1)\ insert\ end\ \"Out\ \[format\ \"%#x\"\ \$portID\]H,\ \[format\ \"%#x\"\ \$outData\]H\"\n\ \ \ \ \n#\ Get\ the\ result\ \nset\ s\ \[::dll::buffer\ 100\]\n::ntport::GetLastState\ s\nset\ s\ \[string\ range\ \$s\ 0\ \[expr\ \[string\ first\ \"\\x00\"\ \$s\]\ -\ 1\]\]\n\$widget(Listbox1)\ insert\ end\ \$s\n\$widget(Listbox1)\ see\ end] \
        -pady 0 -text Write 
    vTcl:DefineAlias "$top.but81" "btnWrite" vTcl:WidgetProc "Toplevel1" 1
    button $top.but82 \
        -command exit -pady 0 -text Close 
    vTcl:DefineAlias "$top.but82" "btnClose" vTcl:WidgetProc "Toplevel1" 1
    label $top.lab90 \
        -text {Copyright (c) 1997-2006, Zeal SoftStudio. www.zealsoft.com} 
    vTcl:DefineAlias "$top.lab90" "Label4" vTcl:WidgetProc "Toplevel1" 1
    ::iwidgets::labeledframe $top.lab73 \
        -labelfont -Adobe-Helvetica-Bold-R-Normal--*-120-*-*-*-*-*-* \
        -labelpos nw -labeltext Size 
    vTcl:DefineAlias "$top.lab73" "Labeledframe1" vTcl:WidgetProc "Toplevel1" 1
    set site_4_0 [$top.lab73 childsite]
    radiobutton $site_4_0.cpd74 \
        -text Byte -value byte -variable "$top\::selectedButton" 
    vTcl:DefineAlias "$site_4_0.cpd74" "Radiobutton1" vTcl:WidgetProc "Toplevel1" 1
    radiobutton $site_4_0.cpd75 \
        -text Word -value word -variable "$top\::selectedButton" 
    vTcl:DefineAlias "$site_4_0.cpd75" "Radiobutton2" vTcl:WidgetProc "Toplevel1" 1
    radiobutton $site_4_0.cpd76 \
        -text DWord -value dword -variable "$top\::selectedButton" 
    vTcl:DefineAlias "$site_4_0.cpd76" "Radiobutton3" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_0.cpd74 \
        -in $site_4_0 -x 5 -y 5 -anchor nw -bordermode inside 
    place $site_4_0.cpd75 \
        -in $site_4_0 -x 70 -y 5 -anchor nw -bordermode inside 
    place $site_4_0.cpd76 \
        -in $site_4_0 -x 145 -y 5 -anchor nw -bordermode inside 
    scrollbar $top.scr79
    vTcl:DefineAlias "$top.scr79" "Scrollbar1" vTcl:WidgetProc "Toplevel1" 1
    ###################
    # SETTING GEOMETRY
    ###################
    place $top.lab74 \
        -in $top -x 10 -y 10 -anchor nw -bordermode ignore 
    place $top.ent75 \
        -in $top -x 85 -y 10 -width 41 -height 19 -anchor nw \
        -bordermode ignore 
    place $top.lab76 \
        -in $top -x 135 -y 10 -anchor nw -bordermode ignore 
    place $top.ent77 \
        -in $top -x 195 -y 10 -width 46 -height 19 -anchor nw \
        -bordermode ignore 
    place $top.lab78 \
        -in $top -x 15 -y 35 -anchor nw -bordermode ignore 
    place $top.lis79 \
        -in $top -x 15 -y 55 -width 221 -height 86 -anchor nw \
        -bordermode ignore 
    place $top.but80 \
        -in $top -x 265 -y 10 -width 59 -height 21 -anchor nw \
        -bordermode ignore 
    place $top.but81 \
        -in $top -x 265 -y 40 -width 59 -height 21 -anchor nw \
        -bordermode ignore 
    place $top.but82 \
        -in $top -x 265 -y 70 -width 59 -height 21 -anchor nw \
        -bordermode ignore 
    place $top.lab90 \
        -in $top -x 10 -y 200 -anchor nw -bordermode ignore 
    place $top.lab73 \
        -in $top -x 5 -y 140 -width 233 -height 62 -anchor nw \
        -bordermode ignore 
    place $top.scr79 \
        -in $top -x 215 -y 60 -width 17 -height 76 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}

Window show .
Window show .top73

main $argc $argv
